==> ec2-1.8.0.DEVPREVIEW-sources.jar: software/amazon/awscdk/services/ec2/CfnVPCGatewayAttachmentProps.java <==
package software.amazon.awscdk.services.ec2;

/**
 * Properties for defining a `AWS::EC2::VPCGatewayAttachment`.
 * 
 * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ec2-vpc-gateway-attachment.html
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.16.0 (build 98909b5)", date = "2019-09-10T21:16:48.814Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
public interface CfnVPCGatewayAttachmentProps extends software.amazon.jsii.JsiiSerializable {
    /**
     * `AWS::EC2::VPCGatewayAttachment.VpcId`.
     * 
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ec2-vpc-gateway-attachment.html#cfn-ec2-vpcgatewayattachment-vpcid
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    java.lang.String getVpcId();

    /**
     * `AWS::EC2::VPCGatewayAttachment.InternetGatewayId`.
     * 
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ec2-vpc-gateway-attachment.html#cfn-ec2-vpcgatewayattachment-internetgatewayid
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    java.lang.String getInternetGatewayId();

    /**
     * `AWS::EC2::VPCGatewayAttachment.VpnGatewayId`.
     * 
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ec2-vpc-gateway-attachment.html#cfn-ec2-vpcgatewayattachment-vpngatewayid
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    java.lang.String getVpnGatewayId();

    /**
     * @return a {@link Builder} of {@link CfnVPCGatewayAttachmentProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    static Builder builder() {
        return new Builder();
    }

    /**
     * A builder for {@link CfnVPCGatewayAttachmentProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    final class Builder {
        private java.lang.String vpcId;
        private java.lang.String internetGatewayId;
        private java.lang.String vpnGatewayId;

        /**
         * Sets the value of VpcId
         * @param vpcId `AWS::EC2::VPCGatewayAttachment.VpcId`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public Builder vpcId(java.lang.String vpcId) {
            this.vpcId = vpcId;
            return this;
        }

        /**
         * Sets the value of InternetGatewayId
         * @param internetGatewayId `AWS::EC2::VPCGatewayAttachment.InternetGatewayId`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public Builder internetGatewayId(java.lang.String internetGatewayId) {
            this.internetGatewayId = internetGatewayId;
            return this;
        }

        /**
         * Sets the value of VpnGatewayId
         * @param vpnGatewayId `AWS::EC2::VPCGatewayAttachment.VpnGatewayId`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public Builder vpnGatewayId(java.lang.String vpnGatewayId) {
            this.vpnGatewayId = vpnGatewayId;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link CfnVPCGatewayAttachmentProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public CfnVPCGatewayAttachmentProps build() {
            return new Jsii$Proxy(vpcId, internetGatewayId, vpnGatewayId);
        }

    }

    /**
     * An implementation for {@link CfnVPCGatewayAttachmentProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements CfnVPCGatewayAttachmentProps {
        private final java.lang.String vpcId;
        private final java.lang.String internetGatewayId;
        private final java.lang.String vpnGatewayId;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.setObjRef(objRef);
            this.vpcId = this.jsiiGet("vpcId", java.lang.String.class);
            this.internetGatewayId = this.jsiiGet("internetGatewayId", java.lang.String.class);
            this.vpnGatewayId = this.jsiiGet("vpnGatewayId", java.lang.String.class);
        }


        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        private Jsii$Proxy(java.lang.String vpcId, java.lang.String internetGatewayId, java.lang.String vpnGatewayId) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.vpcId = java.util.Objects.requireNonNull(vpcId, "vpcId is required");
            this.internetGatewayId = internetGatewayId;
            this.vpnGatewayId = vpnGatewayId;
        }

        @Override
        public java.lang.String getVpcId() {
            return this.vpcId;
        }

        @Override
        public java.lang.String getInternetGatewayId() {
            return this.internetGatewayId;
        }

        @Override
        public java.lang.String getVpnGatewayId() {
            return this.vpnGatewayId;
        }

        @Override
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("vpcId", om.valueToTree(this.getVpcId()));
            if (this.getInternetGatewayId() != null) {
                obj.set("internetGatewayId", om.valueToTree(this.getInternetGatewayId()));
            }
            if (this.getVpnGatewayId() != null) {
                obj.set("vpnGatewayId", om.valueToTree(this.getVpnGatewayId()));
            }
            return obj;
        }

        @Override
        public boolean equals(Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            CfnVPCGatewayAttachmentProps.Jsii$Proxy that = (CfnVPCGatewayAttachmentProps.Jsii$Proxy) o;

            if (!vpcId.equals(that.vpcId)) return false;
            if (this.internetGatewayId != null ? !this.internetGatewayId.equals(that.internetGatewayId) : that.internetGatewayId != null) return false;
            return this.vpnGatewayId != null ? this.vpnGatewayId.equals(that.vpnGatewayId) : that.vpnGatewayId == null;
        }

        @Override
        public int hashCode() {
            int result = this.vpcId.hashCode();
            result = 31 * result + (this.internetGatewayId != null ? this.internetGatewayId.hashCode() : 0);
            result = 31 * result + (this.vpnGatewayId != null ? this.vpnGatewayId.hashCode() : 0);
            return result;
        }

    }
}

==> ec2-1.9.0.DEVPREVIEW-sources.jar: software/amazon/awscdk/services/ec2/CfnVPCGatewayAttachmentProps.java <==
package software.amazon.awscdk.services.ec2;

/**
 * Properties for defining a `AWS::EC2::VPCGatewayAttachment`.
 * 
 * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ec2-vpc-gateway-attachment.html
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.17.0 (build 7d5d104)", date = "2019-09-20T09:56:19.014Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
public interface CfnVPCGatewayAttachmentProps extends software.amazon.jsii.JsiiSerializable {

    /**
     * `AWS::EC2::VPCGatewayAttachment.VpcId`.
     * 
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ec2-vpc-gateway-attachment.html#cfn-ec2-vpcgatewayattachment-vpcid
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    java.lang.String getVpcId();

    /**
     * `AWS::EC2::VPCGatewayAttachment.InternetGatewayId`.
     * 
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ec2-vpc-gateway-attachment.html#cfn-ec2-vpcgatewayattachment-internetgatewayid
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    java.lang.String getInternetGatewayId();

    /**
     * `AWS::EC2::VPCGatewayAttachment.VpnGatewayId`.
     * 
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ec2-vpc-gateway-attachment.html#cfn-ec2-vpcgatewayattachment-vpngatewayid
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    java.lang.String getVpnGatewayId();

    /**
     * @return a {@link Builder} of {@link CfnVPCGatewayAttachmentProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link CfnVPCGatewayAttachmentProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    public static final class Builder {
        private java.lang.String vpcId;
        private java.lang.String internetGatewayId;
        private java.lang.String vpnGatewayId;

        /**
         * Sets the value of VpcId
         * @param vpcId `AWS::EC2::VPCGatewayAttachment.VpcId`. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public Builder vpcId(java.lang.String vpcId) {
            this.vpcId = vpcId;
            return this;
        }

        /**
         * Sets the value of InternetGatewayId
         * @param internetGatewayId `AWS::EC2::VPCGatewayAttachment.InternetGatewayId`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public Builder internetGatewayId(java.lang.String internetGatewayId) {
            this.internetGatewayId = internetGatewayId;
            return this;
        }

        /**
         * Sets the value of VpnGatewayId
         * @param vpnGatewayId `AWS::EC2::VPCGatewayAttachment.VpnGatewayId`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public Builder vpnGatewayId(java.lang.String vpnGatewayId) {
            this.vpnGatewayId = vpnGatewayId;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link CfnVPCGatewayAttachmentProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public CfnVPCGatewayAttachmentProps build() {
            return new Jsii$Proxy(vpcId, internetGatewayId, vpnGatewayId);
        }
    }

    /**
     * An implementation for {@link CfnVPCGatewayAttachmentProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements CfnVPCGatewayAttachmentProps {
        private final java.lang.String vpcId;
        private final java.lang.String internetGatewayId;
        private final java.lang.String vpnGatewayId;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.setObjRef(objRef);
            this.vpcId = this.jsiiGet("vpcId", java.lang.String.class);
            this.internetGatewayId = this.jsiiGet("internetGatewayId", java.lang.String.class);
            this.vpnGatewayId = this.jsiiGet("vpnGatewayId", java.lang.String.class);
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        private Jsii$Proxy(java.lang.String vpcId, java.lang.String internetGatewayId, java.lang.String vpnGatewayId) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.vpcId = java.util.Objects.requireNonNull(vpcId, "vpcId is required");
            this.internetGatewayId = internetGatewayId;
            this.vpnGatewayId = vpnGatewayId;
        }

        @Override
        public java.lang.String getVpcId() {
            return this.vpcId;
        }

        @Override
        public java.lang.String getInternetGatewayId() {
            return this.internetGatewayId;
        }

        @Override
        public java.lang.String getVpnGatewayId() {
            return this.vpnGatewayId;
        }

        @Override
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("vpcId", om.valueToTree(this.getVpcId()));
            if (this.getInternetGatewayId() != null) {
                obj.set("internetGatewayId", om.valueToTree(this.getInternetGatewayId()));
            }
            if (this.getVpnGatewayId() != null) {
                obj.set("vpnGatewayId", om.valueToTree(this.getVpnGatewayId()));
            }
            return obj;
        }

        @Override
        public boolean equals(Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            CfnVPCGatewayAttachmentProps.Jsii$Proxy that = (CfnVPCGatewayAttachmentProps.Jsii$Proxy) o;

            if (!vpcId.equals(that.vpcId)) return false;
            if (this.internetGatewayId != null ? !this.internetGatewayId.equals(that.internetGatewayId) : that.internetGatewayId != null) return false;
            return this.vpnGatewayId != null ? this.vpnGatewayId.equals(that.vpnGatewayId) : that.vpnGatewayId == null;
        }

        @Override
        public int hashCode() {
            int result = this.vpcId.hashCode();
            result = 31 * result + (this.internetGatewayId != null ? this.internetGatewayId.hashCode() : 0);
            result = 31 * result + (this.vpnGatewayId != null ? this.vpnGatewayId.hashCode() : 0);
            return result;
        }
    }
}
